@@ -61,6 +61,7 @@ from .custom_types import (
     _CUSTOM_Float,
     _CUSTOM_Time,
 )
+from .util import _update_connection_application_name
 
 colspecs = {
     Date: _CUSTOM_Date,
@@ -252,6 +253,8 @@ class SnowflakeDialect(default.DefaultDialect):
     def normalize_name(self, name):
         if name is None:
             return None
+        if name == "":
+            return ""
         if name.upper() == name and not self.identifier_preparer._requires_quotes(
             name.lower()
         ):
@@ -264,6 +267,8 @@ class SnowflakeDialect(default.DefaultDialect):
     def denormalize_name(self, name):
         if name is None:
             return None
+        if name == "":
+            return ""
         elif name.lower() == name and not self.identifier_preparer._requires_quotes(
             name.lower()
         ):
@@ -830,6 +835,12 @@ class SnowflakeDialect(default.DefaultDialect):
             else None
         }
 
+    def connect(self, *cargs, **cparams):
+        snowflake_conn = super().connect(
+            *cargs, **_update_connection_application_name(**cparams)
+        )
+        return snowflake_conn
+
 
 @sa_vnt.listens_for(Table, "before_create")
 def check_table(table, connection, _ddl_runner, **kw):
